@@ -133,7 +133,7 @@ KateCompletionWidget::KateCompletionWidget(KTextEditor::ViewPrivate *parent)
 
     m_entryList->setVerticalScrollMode(QAbstractItemView::ScrollPerItem);
 
-    m_argumentHintTree->setParent(0, Qt::ToolTip);
+    m_argumentHintTree->setParent(nullptr, Qt::ToolTip);
     m_argumentHintTree->setModel(m_argumentHintModel);
 
     // trigger completion on double click on completion list
@@ -413,7 +413,7 @@ void KateCompletionWidget::startCompletion(const KTextEditor::Range &word, const
 
         disconnect(model, SIGNAL(waitForReset()), this, SLOT(waitForModelReset()));
 
-        m_completionRanges[model] = view()->doc()->newMovingRange(range, KTextEditor::MovingRange::ExpandRight | KTextEditor::MovingRange::ExpandLeft);
+        m_completionRanges[model] = CompletionRange(view()->doc()->newMovingRange(range, KTextEditor::MovingRange::ExpandRight | KTextEditor::MovingRange::ExpandLeft));
 
         //In automatic invocation mode, hide the completion widget as soon as the position where the completion was started is passed to the left
         m_completionRanges[model].leftBoundary = view()->cursorPosition();
@@ -542,8 +542,6 @@ bool KateCompletionWidget::updatePosition(bool force)
 
     updateHeight();
 
-    updateArgumentHintGeometry();
-
 //   //qCDebug(LOG_KTE) << "updated to" << geometry() << m_entryList->geometry() << borderHit;
 
     return borderHit;
@@ -706,7 +704,7 @@ void KateCompletionWidget::cursorPositionChanged()
         oldCurrentSourceIndex = m_presentationModel->mapToSource(m_entryList->currentIndex());
     }
 
-    //Check the models and eventuall abort some
+    //Check the models and eventually abort some
     const QList<KTextEditor::CodeCompletionModel *> checkCompletionRanges = m_completionRanges.keys();
     for (QList<KTextEditor::CodeCompletionModel *>::const_iterator it = checkCompletionRanges.begin(); it != checkCompletionRanges.end(); ++it) {
         KTextEditor::CodeCompletionModel *model = *it;
@@ -908,6 +906,21 @@ void KateCompletionWidget::execute()
 void KateCompletionWidget::resizeEvent(QResizeEvent *event)
 {
     QFrame::resizeEvent(event);
+
+    // keep argument hint geometry in sync
+    if (m_argumentHintTree->isVisible()) {
+        updateArgumentHintGeometry();
+    }
+}
+
+void KateCompletionWidget::moveEvent(QMoveEvent *event)
+{
+    QFrame::moveEvent(event);
+
+    // keep argument hint geometry in sync
+    if (m_argumentHintTree->isVisible()) {
+        updateArgumentHintGeometry();
+    }
 }
 
 void KateCompletionWidget::showEvent(QShowEvent *event)
@@ -925,7 +938,7 @@ KTextEditor::MovingRange *KateCompletionWidget::completionRange(KTextEditor::Cod
 {
     if (!model) {
         if (m_completionRanges.isEmpty()) {
-            return 0;
+            return nullptr;
         }
 
         KTextEditor::MovingRange *ret = m_completionRanges.begin()->range;
@@ -939,7 +952,7 @@ KTextEditor::MovingRange *KateCompletionWidget::completionRange(KTextEditor::Cod
     if (m_completionRanges.contains(model)) {
         return m_completionRanges[model].range;
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
@@ -1136,7 +1149,7 @@ QWidget *KateCompletionWidget::currentEmbeddedWidget()
 {
     QModelIndex index = selectedIndex();
     if (!index.isValid()) {
-        return 0;
+        return nullptr;
     }
     if (qobject_cast<const ExpandingWidgetModel *>(index.model())) {
         const ExpandingWidgetModel *model = static_cast<const ExpandingWidgetModel *>(index.model());
@@ -1144,7 +1157,7 @@ QWidget *KateCompletionWidget::currentEmbeddedWidget()
             return model->expandingWidget(index);
         }
     }
-    return 0;
+    return nullptr;
 }
 
 void KateCompletionWidget::cursorDown()
