@@ -47,7 +47,7 @@ public:
      * Constructor
      * @param document the document the undo item belongs to
      */
-    KateUndo(KTextEditor::DocumentPrivate *document);
+    explicit KateUndo(KTextEditor::DocumentPrivate *document);
 
     /**
      * Destructor
@@ -80,6 +80,7 @@ public:
     /**
      * merge an undo item
      * Saves a bit of memory and potentially many calls when undo/redoing.
+     * Only called for equal types of this object and the passed one.
      * @param undo undo item to merge
      * @return success
      */
@@ -157,38 +158,38 @@ public:
     }
 
 private:
-    uchar m_lineModFlags;
+    uchar m_lineModFlags = 0x0;
 };
 
 class KateEditInsertTextUndo : public KateUndo
 {
 public:
-    KateEditInsertTextUndo(KTextEditor::DocumentPrivate *document, int line, int col, const QString &text);
+    explicit KateEditInsertTextUndo(KTextEditor::DocumentPrivate *document, int line, int col, const QString &text);
 
     /**
      * @copydoc KateUndo::isEmpty()
      */
-    bool isEmpty() const Q_DECL_OVERRIDE;
+    bool isEmpty() const override;
 
     /**
      * @copydoc KateUndo::undo()
      */
-    void undo() Q_DECL_OVERRIDE;
+    void undo() override;
 
     /**
      * @copydoc KateUndo::redo()
      */
-    void redo() Q_DECL_OVERRIDE;
+    void redo() override;
 
     /**
      * @copydoc KateUndo::mergeWith(const KateUndo)
      */
-    bool mergeWith(const KateUndo *undo) Q_DECL_OVERRIDE;
+    bool mergeWith(const KateUndo *undo) override;
 
     /**
      * @copydoc KateUndo::type()
      */
-    KateUndo::UndoType type() const Q_DECL_OVERRIDE
+    KateUndo::UndoType type() const override
     {
         return KateUndo::editInsertText;
     }
@@ -212,32 +213,32 @@ private:
 class KateEditRemoveTextUndo : public KateUndo
 {
 public:
-    KateEditRemoveTextUndo(KTextEditor::DocumentPrivate *document, int line, int col, const QString &text);
+    explicit KateEditRemoveTextUndo(KTextEditor::DocumentPrivate *document, int line, int col, const QString &text);
 
     /**
      * @copydoc KateUndo::isEmpty()
      */
-    bool isEmpty() const Q_DECL_OVERRIDE;
+    bool isEmpty() const override;
 
     /**
      * @copydoc KateUndo::undo()
      */
-    void undo() Q_DECL_OVERRIDE;
+    void undo() override;
 
     /**
      * @copydoc KateUndo::redo()
      */
-    void redo() Q_DECL_OVERRIDE;
+    void redo() override;
 
     /**
      * @copydoc KateUndo::mergeWith(const KateUndo)
      */
-    bool mergeWith(const KateUndo *undo) Q_DECL_OVERRIDE;
+    bool mergeWith(const KateUndo *undo) override;
 
     /**
      * @copydoc KateUndo::type()
      */
-    KateUndo::UndoType type() const Q_DECL_OVERRIDE
+    KateUndo::UndoType type() const override
     {
         return KateUndo::editRemoveText;
     }
@@ -261,7 +262,7 @@ private:
 class KateEditMarkLineAutoWrappedUndo : public KateUndo
 {
 public:
-    KateEditMarkLineAutoWrappedUndo(KTextEditor::DocumentPrivate *document, int line, bool autowrapped)
+    explicit KateEditMarkLineAutoWrappedUndo(KTextEditor::DocumentPrivate *document, int line, bool autowrapped)
         : KateUndo(document)
         , m_line(line)
         , m_autowrapped(autowrapped)
@@ -270,17 +271,17 @@ public:
     /**
      * @copydoc KateUndo::undo()
      */
-    void undo() Q_DECL_OVERRIDE;
+    void undo() override;
 
     /**
      * @copydoc KateUndo::redo()
      */
-    void redo() Q_DECL_OVERRIDE;
+    void redo() override;
 
     /**
      * @copydoc KateUndo::type()
      */
-    KateUndo::UndoType type() const Q_DECL_OVERRIDE
+    KateUndo::UndoType type() const override
     {
         return KateUndo::editMarkLineAutoWrapped;
     }
@@ -293,22 +294,22 @@ private:
 class KateEditWrapLineUndo : public KateUndo
 {
 public:
-    KateEditWrapLineUndo(KTextEditor::DocumentPrivate *document, int line, int col, int len, bool newLine);
+    explicit KateEditWrapLineUndo(KTextEditor::DocumentPrivate *document, int line, int col, int len, bool newLine);
 
     /**
      * @copydoc KateUndo::undo()
      */
-    void undo() Q_DECL_OVERRIDE;
+    void undo() override;
 
     /**
      * @copydoc KateUndo::redo()
      */
-    void redo() Q_DECL_OVERRIDE;
+    void redo() override;
 
     /**
      * @copydoc KateUndo::type()
      */
-    KateUndo::UndoType type() const Q_DECL_OVERRIDE
+    KateUndo::UndoType type() const override
     {
         return KateUndo::editWrapLine;
     }
@@ -329,22 +330,22 @@ private:
 class KateEditUnWrapLineUndo : public KateUndo
 {
 public:
-    KateEditUnWrapLineUndo(KTextEditor::DocumentPrivate *document, int line, int col, int len, bool removeLine);
+    explicit KateEditUnWrapLineUndo(KTextEditor::DocumentPrivate *document, int line, int col, int len, bool removeLine);
 
     /**
      * @copydoc KateUndo::undo()
      */
-    void undo() Q_DECL_OVERRIDE;
+    void undo() override;
 
     /**
      * @copydoc KateUndo::redo()
      */
-    void redo() Q_DECL_OVERRIDE;
+    void redo() override;
 
     /**
      * @copydoc KateUndo::type()
      */
-    KateUndo::UndoType type() const Q_DECL_OVERRIDE
+    KateUndo::UndoType type() const override
     {
         return KateUndo::editUnWrapLine;
     }
@@ -365,22 +366,22 @@ private:
 class KateEditInsertLineUndo : public KateUndo
 {
 public:
-    KateEditInsertLineUndo(KTextEditor::DocumentPrivate *document, int line, const QString &text);
+    explicit KateEditInsertLineUndo(KTextEditor::DocumentPrivate *document, int line, const QString &text);
 
     /**
      * @copydoc KateUndo::undo()
      */
-    void undo() Q_DECL_OVERRIDE;
+    void undo() override;
 
     /**
      * @copydoc KateUndo::redo()
      */
-    void redo() Q_DECL_OVERRIDE;
+    void redo() override;
 
     /**
      * @copydoc KateUndo::type()
      */
-    KateUndo::UndoType type() const Q_DECL_OVERRIDE
+    KateUndo::UndoType type() const override
     {
         return KateUndo::editInsertLine;
     }
@@ -399,22 +400,22 @@ private:
 class KateEditRemoveLineUndo : public KateUndo
 {
 public:
-    KateEditRemoveLineUndo(KTextEditor::DocumentPrivate *document, int line, const QString &text);
+    explicit KateEditRemoveLineUndo(KTextEditor::DocumentPrivate *document, int line, const QString &text);
 
     /**
      * @copydoc KateUndo::undo()
      */
-    void undo() Q_DECL_OVERRIDE;
+    void undo() override;
 
     /**
      * @copydoc KateUndo::redo()
      */
-    void redo() Q_DECL_OVERRIDE;
+    void redo() override;
 
     /**
      * @copydoc KateUndo::type()
      */
-    KateUndo::UndoType type() const Q_DECL_OVERRIDE
+    KateUndo::UndoType type() const override
     {
         return KateUndo::editRemoveLine;
     }
@@ -544,7 +545,7 @@ private:
     /**
      * prohibit merging with the next group
      */
-    bool m_safePoint;
+    bool m_safePoint = false;
 
     /**
      * the text selection of the active view before the edit step
