@@ -85,7 +85,7 @@ KateGlobalConfig::KateGlobalConfig()
     s_global = this;
 
     // init with defaults from config or really hardcoded ones
-    KConfigGroup cg(KTextEditor::EditorPrivate::config(), "Editor");
+    KConfigGroup cg(KTextEditor::EditorPrivate::config(), "KTextEditor Editor");
     readConfig(cg);
 }
 
@@ -118,7 +118,7 @@ void KateGlobalConfig::writeConfig(KConfigGroup &config)
 void KateGlobalConfig::updateConfig()
 {
     // write config
-    KConfigGroup cg(KTextEditor::EditorPrivate::config(), "Editor");
+    KConfigGroup cg(KTextEditor::EditorPrivate::config(), "KTextEditor Editor");
     writeConfig(cg);
     KTextEditor::EditorPrivate::config()->sync();
 }
@@ -201,7 +201,7 @@ KateDocumentConfig::KateDocumentConfig()
     s_global = this;
 
     // init with defaults from config or really hardcoded ones
-    KConfigGroup cg(KTextEditor::EditorPrivate::config(), "Document");
+    KConfigGroup cg(KTextEditor::EditorPrivate::config(), "KTextEditor Document");
     readConfig(cg);
 }
 
@@ -438,7 +438,7 @@ void KateDocumentConfig::updateConfig()
         }
 
         // write config
-        KConfigGroup cg(KTextEditor::EditorPrivate::config(), "Document");
+        KConfigGroup cg(KTextEditor::EditorPrivate::config(), "KTextEditor Document");
         writeConfig(cg);
         KTextEditor::EditorPrivate::config()->sync();
     }
@@ -523,7 +523,7 @@ void KateDocumentConfig::setIndentationMode(const QString &indentationMode)
 
 uint KateDocumentConfig::tabHandling() const
 {
-    // This setting is purly a user preference,
+    // This setting is purely a user preference,
     // hence, there exists only the global setting.
     if (isGlobal()) {
         return m_tabHandling;
@@ -1229,55 +1229,7 @@ KateViewConfig::KateViewConfig()
     :
 
     m_dynWordWrapSet(false),
-    m_dynWordWrapIndicatorsSet(false),
-    m_dynWordWrapAlignIndentSet(false),
-    m_lineNumbersSet(false),
-    m_scrollBarMarksSet(false),
-    m_scrollBarPreviewSet(false),
-    m_scrollBarMiniMapSet(false),
-    m_scrollBarMiniMapAllSet(false),
-    m_scrollBarMiniMapWidthSet(false),
-    m_showScrollbarsSet(false),
-    m_iconBarSet(false),
-    m_foldingBarSet(false),
-    m_foldingPreviewSet(false),
-    m_lineModificationSet(false),
-    m_bookmarkSortSet(false),
-    m_autoCenterLinesSet(false),
-    m_searchFlagsSet(false),
-    m_defaultMarkTypeSet(false),
-    m_persistentSelectionSet(false),
-    m_inputModeSet(false),
-    m_viInputModeStealKeysSet(false),
-    m_viRelativeLineNumbersSet(false),
-    m_automaticCompletionInvocationSet(false),
-    m_wordCompletionSet(false),
-    m_keywordCompletionSet(false),
-    m_wordCompletionMinimalWordLengthSet(false),
-    m_smartCopyCutSet(false),
-    m_scrollPastEndSet(false),
-    m_allowMarkMenu(true),
-    m_wordCompletionRemoveTailSet(false),
-    m_foldFirstLineSet (false),
-    m_showWordCountSet(false),
-    m_showLinesCountSet(false),
-    m_autoBracketsSet(false),
-    m_backspaceRemoveComposedSet(false)
-
-{
-    s_global = this;
-
-    // init with defaults from config or really hardcoded ones
-    KConfigGroup config(KTextEditor::EditorPrivate::config(), "View");
-    readConfig(config);
-}
-
-KateViewConfig::KateViewConfig(KTextEditor::ViewPrivate *view)
-    :
-    m_searchFlags(PowerModePlainText),
-    m_maxHistorySize(100),
-    m_showWordCount(false),
-    m_dynWordWrapSet(false),
+    m_dynWrapAtStaticMarkerSet(false),
     m_dynWordWrapIndicatorsSet(false),
     m_dynWordWrapAlignIndentSet(false),
     m_lineNumbersSet(false),
@@ -1308,6 +1260,58 @@ KateViewConfig::KateViewConfig(KTextEditor::ViewPrivate *view)
     m_allowMarkMenu(true),
     m_wordCompletionRemoveTailSet(false),
     m_foldFirstLineSet(false),
+    m_showWordCountSet(false),
+    m_showLineCountSet(false),
+    m_autoBracketsSet(false),
+    m_backspaceRemoveComposedSet(false)
+
+{
+    s_global = this;
+
+    // init with defaults from config or really hardcoded ones
+    KConfigGroup config(KTextEditor::EditorPrivate::config(), "KTextEditor View");
+    readConfig(config);
+}
+
+KateViewConfig::KateViewConfig(KTextEditor::ViewPrivate *view)
+    :
+    m_searchFlags(PowerModePlainText),
+    m_maxHistorySize(100),
+    m_showWordCount(false),
+    m_dynWordWrapSet(false),
+    m_dynWrapAtStaticMarkerSet(false),
+    m_dynWordWrapIndicatorsSet(false),
+    m_dynWordWrapAlignIndentSet(false),
+    m_lineNumbersSet(false),
+    m_scrollBarMarksSet(false),
+    m_scrollBarPreviewSet(false),
+    m_scrollBarMiniMapSet(false),
+    m_scrollBarMiniMapAllSet(false),
+    m_scrollBarMiniMapWidthSet(false),
+    m_showScrollbarsSet(false),
+    m_iconBarSet(false),
+    m_foldingBarSet(false),
+    m_foldingPreviewSet(false),
+    m_lineModificationSet(false),
+    m_bookmarkSortSet(false),
+    m_autoCenterLinesSet(false),
+    m_searchFlagsSet(false),
+    m_defaultMarkTypeSet(false),
+    m_persistentSelectionSet(false),
+    m_inputModeSet(false),
+    m_viInputModeStealKeysSet(false),
+    m_viRelativeLineNumbersSet(false),
+    m_automaticCompletionInvocationSet(false),
+    m_wordCompletionSet(false),
+    m_keywordCompletionSet(false),
+    m_wordCompletionMinimalWordLengthSet(false),
+    m_smartCopyCutSet(false),
+    m_scrollPastEndSet(false),
+    m_allowMarkMenu(true),
+    m_wordCompletionRemoveTailSet(false),
+    m_foldFirstLineSet(false),
+    m_showWordCountSet(false),
+    m_showLineCountSet(false),
     m_autoBracketsSet(false),
     m_backspaceRemoveComposedSet(false),
     m_view(view)
@@ -1322,6 +1326,7 @@ namespace
 {
 const char KEY_SEARCH_REPLACE_FLAGS[] = "Search/Replace Flags";
 const char KEY_DYN_WORD_WRAP[] = "Dynamic Word Wrap";
+const char KEY_DYN_WORD_WRAP_AT_STATIC_MARKER[] = "Dynamic Word Wrap At Static Marker";
 const char KEY_DYN_WORD_WRAP_INDICATORS[] = "Dynamic Word Wrap Indicators";
 const char KEY_DYN_WORD_WRAP_ALIGN_INDENT[] = "Dynamic Word Wrap Align Indent";
 const char KEY_LINE_NUMBERS[] = "Line Numbers";
@@ -1352,7 +1357,7 @@ const char KEY_WORD_COMPLETION_REMOVE_TAIL[] = "Word Completion Remove Tail";
 const char KEY_SMART_COPY_CUT[] = "Smart Copy Cut";
 const char KEY_SCROLL_PAST_END[] = "Scroll Past End";
 const char KEY_FOLD_FIRST_LINE[] = "Fold First Line";
-const char KEY_SHOW_LINES_COUNT[] = "Show Lines Count";
+const char KEY_SHOW_LINE_COUNT[] = "Show Line Count";
 const char KEY_SHOW_WORD_COUNT[] = "Show Word Count";
 const char KEY_AUTO_BRACKETS[] = "Auto Brackets";
 const char KEY_BACKSPACE_REMOVE_COMPOSED[] = "Backspace Remove Composed Characters";
@@ -1364,6 +1369,7 @@ void KateViewConfig::readConfig(const KConfigGroup &config)
 
     // default on
     setDynWordWrap(config.readEntry(KEY_DYN_WORD_WRAP, true));
+    setDynWrapAtStaticMarker(config.readEntry(KEY_DYN_WORD_WRAP_AT_STATIC_MARKER, false));
     setDynWordWrapIndicators(config.readEntry(KEY_DYN_WORD_WRAP_INDICATORS, 1));
     setDynWordWrapAlignIndent(config.readEntry(KEY_DYN_WORD_WRAP_ALIGN_INDENT, 80));
 
@@ -1415,7 +1421,7 @@ void KateViewConfig::readConfig(const KConfigGroup &config)
     setSmartCopyCut(config.readEntry(KEY_SMART_COPY_CUT, false));
     setScrollPastEnd(config.readEntry(KEY_SCROLL_PAST_END, false));
     setFoldFirstLine(config.readEntry(KEY_FOLD_FIRST_LINE, false));
-    setShowLinesCount(config.readEntry(KEY_SHOW_LINES_COUNT, false));
+    setShowLineCount(config.readEntry(KEY_SHOW_LINE_COUNT, false));
     setShowWordCount(config.readEntry(KEY_SHOW_WORD_COUNT, false));
     setAutoBrackets(config.readEntry(KEY_AUTO_BRACKETS, false));
 
@@ -1427,6 +1433,7 @@ void KateViewConfig::readConfig(const KConfigGroup &config)
 void KateViewConfig::writeConfig(KConfigGroup &config)
 {
     config.writeEntry(KEY_DYN_WORD_WRAP, dynWordWrap());
+    config.writeEntry(KEY_DYN_WORD_WRAP_AT_STATIC_MARKER, dynWrapAtStaticMarker());
     config.writeEntry(KEY_DYN_WORD_WRAP_INDICATORS, dynWordWrapIndicators());
     config.writeEntry(KEY_DYN_WORD_WRAP_ALIGN_INDENT, dynWordWrapAlignIndent());
 
@@ -1480,7 +1487,7 @@ void KateViewConfig::writeConfig(KConfigGroup &config)
     config.writeEntry(KEY_VI_INPUT_MODE_STEAL_KEYS, viInputModeStealKeys());
     config.writeEntry(KEY_VI_RELATIVE_LINE_NUMBERS, viRelativeLineNumbers());
 
-    config.writeEntry(KEY_SHOW_LINES_COUNT, showLinesCount());
+    config.writeEntry(KEY_SHOW_LINE_COUNT, showLineCount());
     config.writeEntry(KEY_SHOW_WORD_COUNT, showWordCount());
     config.writeEntry(KEY_AUTO_BRACKETS, autoBrackets());
 
@@ -1500,7 +1507,7 @@ void KateViewConfig::updateConfig()
         }
 
         // write config
-        KConfigGroup cg(KTextEditor::EditorPrivate::config(), "View");
+        KConfigGroup cg(KTextEditor::EditorPrivate::config(), "KTextEditor View");
         writeConfig(cg);
         KTextEditor::EditorPrivate::config()->sync();
     }
@@ -1529,6 +1536,29 @@ void KateViewConfig::setDynWordWrap(bool wrap)
     configEnd();
 }
 
+bool KateViewConfig::dynWrapAtStaticMarker() const
+{
+    if (m_dynWrapAtStaticMarkerSet || isGlobal()) {
+        return m_dynWrapAtStaticMarker;
+    }
+
+    return s_global->dynWrapAtStaticMarker();
+}
+
+void KateViewConfig::setDynWrapAtStaticMarker(bool on)
+{
+    if (m_dynWrapAtStaticMarkerSet && m_dynWrapAtStaticMarker == on) {
+        return;
+    }
+
+    configStart();
+
+    m_dynWrapAtStaticMarkerSet = true;
+    m_dynWrapAtStaticMarker = on;
+
+    configEnd();
+}
+
 int KateViewConfig::dynWordWrapIndicators() const
 {
     if (m_dynWordWrapIndicatorsSet || isGlobal()) {
@@ -2248,24 +2278,24 @@ void KateViewConfig::setShowWordCount(bool on)
     configEnd();
 }
 
-bool KateViewConfig::showLinesCount() const
+bool KateViewConfig::showLineCount() const
 {
-    if (m_showLinesCountSet || isGlobal()) {
-        return m_showLinesCount;
+    if (m_showLineCountSet || isGlobal()) {
+        return m_showLineCount;
     }
 
-    return s_global->showLinesCount();
+    return s_global->showLineCount();
 }
 
-void KateViewConfig::setShowLinesCount(bool on)
+void KateViewConfig::setShowLineCount(bool on)
 {
-    if (m_showLinesCountSet && m_showLinesCount == on) {
+    if (m_showLineCountSet && m_showLineCount == on) {
         return;
     }
 
     configStart();
-    m_showLinesCountSet = true;
-    m_showLinesCount = on;
+    m_showLineCountSet = true;
+    m_showLineCount = on;
     configEnd();
 }
 
@@ -2331,7 +2361,7 @@ KateRendererConfig::KateRendererConfig()
     s_global = this;
 
     // init with defaults from config or really hardcoded ones
-    KConfigGroup config(KTextEditor::EditorPrivate::config(), "Renderer");
+    KConfigGroup config(KTextEditor::EditorPrivate::config(), "KTextEditor Renderer");
     readConfig(config);
 }
 
@@ -2425,7 +2455,7 @@ void KateRendererConfig::updateConfig()
         }
 
         // write config
-        KConfigGroup cg(KTextEditor::EditorPrivate::config(), "Renderer");
+        KConfigGroup cg(KTextEditor::EditorPrivate::config(), "KTextEditor Renderer");
         writeConfig(cg);
         KTextEditor::EditorPrivate::config()->sync();
     }
