@@ -32,12 +32,17 @@
 #include "plugin.h"
 
 #include "command.h"
+#include "inlinenoteinterface.h"
+#include "inlinenote.h"
+#include "inlinenotedata.h"
+#include "inlinenoteprovider.h"
 #include "markinterface.h"
 #include "modificationinterface.h"
 #include "sessionconfiginterface.h"
 #include "texthintinterface.h"
 
 #include "annotationinterface.h"
+#include "abstractannotationitemdelegate.h"
 
 #include "kateglobal.h"
 #include "kateconfig.h"
@@ -136,6 +141,11 @@ bool View::insertTemplate(const KTextEditor::Cursor& insertPosition,
     return d->insertTemplateInternal(insertPosition, templateString, script);
 }
 
+void View::setViewInputMode(InputMode inputMode)
+{
+    d->setInputMode(inputMode);
+}
+
 ConfigPage::ConfigPage(QWidget *parent)
     : QWidget(parent)
     , d(nullptr)
@@ -168,7 +178,7 @@ Plugin::Plugin(QObject *parent)
 {}
 
 Plugin::~Plugin()
-{}    
+{}
 
 int Plugin::configPages() const
 {
@@ -210,6 +220,103 @@ TextHintProvider::TextHintProvider()
 TextHintProvider::~TextHintProvider()
 {}
 
+InlineNoteInterface::InlineNoteInterface()
+{}
+
+InlineNoteInterface::~InlineNoteInterface()
+{}
+
+InlineNoteProvider::InlineNoteProvider()
+{}
+
+InlineNoteProvider::~InlineNoteProvider()
+{}
+
+KateInlineNoteData::KateInlineNoteData(KTextEditor::InlineNoteProvider* provider,
+                                       const KTextEditor::View* view,
+                                       const KTextEditor::Cursor& position,
+                                       int index,
+                                       bool underMouse,
+                                       const QFont& font,
+                                       int lineHeight)
+    : m_provider(provider)
+    , m_view(view)
+    , m_position(position)
+    , m_index(index)
+    , m_underMouse(underMouse)
+    , m_font(font)
+    , m_lineHeight(lineHeight)
+{}
+
+InlineNote::InlineNote(const KateInlineNoteData& data)
+    : d(data)
+{
+}
+
+qreal InlineNote::width() const
+{
+    return d.m_provider->inlineNoteSize(*this).width();
+}
+
+bool KTextEditor::InlineNote::underMouse() const
+{
+    return d.m_underMouse;
+}
+
+void KTextEditor::InlineNoteProvider::inlineNoteActivated(const InlineNote& note, Qt::MouseButtons buttons, const QPoint& globalPos)
+{
+    Q_UNUSED(note);
+    Q_UNUSED(buttons);
+    Q_UNUSED(globalPos);
+}
+
+void KTextEditor::InlineNoteProvider::inlineNoteFocusInEvent(const KTextEditor::InlineNote& note, const QPoint& globalPos)
+{
+    Q_UNUSED(note);
+    Q_UNUSED(globalPos);
+}
+
+void KTextEditor::InlineNoteProvider::inlineNoteFocusOutEvent(const KTextEditor::InlineNote& note)
+{
+    Q_UNUSED(note);
+}
+
+void KTextEditor::InlineNoteProvider::inlineNoteMouseMoveEvent(const KTextEditor::InlineNote& note, const QPoint& globalPos)
+{
+    Q_UNUSED(note);
+    Q_UNUSED(globalPos);
+}
+
+KTextEditor::InlineNoteProvider* InlineNote::provider() const
+{
+    return d.m_provider;
+}
+
+const KTextEditor::View* InlineNote::view() const
+{
+    return d.m_view;
+}
+
+QFont InlineNote::font() const
+{
+    return d.m_font;
+}
+
+int InlineNote::index() const
+{
+    return d.m_index;
+}
+
+int InlineNote::lineHeight() const
+{
+    return d.m_lineHeight;
+}
+
+KTextEditor::Cursor InlineNote::position() const
+{
+    return d.m_position;
+}
+
 Command::Command(const QStringList &cmds, QObject *parent)
     : QObject(parent)
     , m_cmds (cmds)
@@ -274,3 +381,25 @@ QRect View::textAreaRect() const
 {
     return d->textAreaRectInternal();
 }
+
+StyleOptionAnnotationItem::StyleOptionAnnotationItem()
+    : contentFontMetrics(QFont())
+{}
+
+StyleOptionAnnotationItem::StyleOptionAnnotationItem(const StyleOptionAnnotationItem &other)
+    : QStyleOption(Version, Type)
+    , contentFontMetrics(QFont())
+{
+    *this = other;
+}
+
+StyleOptionAnnotationItem::StyleOptionAnnotationItem(int version)
+    : QStyleOption(version, Type)
+    , contentFontMetrics(QFont())
+{}
+
+AbstractAnnotationItemDelegate::AbstractAnnotationItemDelegate(QObject *parent)
+    : QObject(parent)
+{}
+
+AbstractAnnotationItemDelegate::~AbstractAnnotationItemDelegate() = default;
