@@ -197,8 +197,7 @@ QString CommandMode::executeCommand ( const QString& commandToExecute )
 
             // The following commands changes the focus themselves, so bar should be hidden before execution.
 
-            // We got a range and a valid command, but the command does not inherit the RangeCommand
-            // extension. Bail out.
+            // We got a range and a valid command, but the command does not support ranges.
             if (range.isValid() && !p->supportsRange(cmd)) {
                 commandResponseMessage = i18n("Error: No range allowed for command \"%1\".",  cmd);
             } else {
@@ -224,7 +223,7 @@ QString CommandMode::executeCommand ( const QString& commandToExecute )
     }
 
     // the following commands change the focus themselves
-    if (!QRegExp(QLatin1String("buffer|b|new|vnew|bp|bprev|bn|bnext|bf|bfirst|bl|blast|edit|e")).exactMatch(cmd.split(QLatin1String(" ")).at(0))) {
+    if (!QRegExp(QLatin1String("buffer|b|new|vnew|bp|bprev|tabp|tabprev|bn|bnext|tabn|tabnext|bf|bfirst|tabf|tabfirst|bl|blast|tabl|tablast|e|edit|tabe|tabedit|tabnew")).exactMatch(cmd.split(QLatin1Char(' ')).at(0))) {
         view()->setFocus();
     }
 
